@@ -147,7 +147,7 @@ class CommonColumns(BaseModel):  # type: ignore
         return make_etag(etag_fields)
 
     @with_default_session
-    def insert(self, session: Session, commit: bool = True, compute_etag: bool = True):
+    def insert(self, session: Session, commit: bool = True):
         """Add the current instance to the session."""
         # Compute an _etag if none was provided
         self._etag = self._etag or self.compute_etag()
@@ -522,7 +522,9 @@ class Permissions(CommonColumns):
 
     @with_default_session
     def insert(
-        self, session: Session, commit: bool = True, compute_etag: bool = True
+        self,
+        session: Session,
+        commit: bool = True,
     ) -> None:
         """
         Insert this permission record into the database and add a corresponding IAM policy binding
@@ -598,7 +600,7 @@ class Permissions(CommonColumns):
             session.delete(perm)
 
         # Always commit, because we don't want to grant IAM download unless this insert succeeds.
-        super().insert(session=session, commit=True, compute_etag=compute_etag)
+        super().insert(session=session, commit=True)
 
         # Don't make any GCS changes if this user doesn't have download access
         if is_network_viewer:
@@ -1270,14 +1272,13 @@ class TrialMetadata(CommonColumns):
         self,
         session: Session,
         commit: bool = True,
-        compute_etag: bool = True,
         validate_metadata: bool = True,
     ):
         """Add the current instance to the session. Skip JSON metadata validation validate_metadata=False."""
         if self.metadata_json is not None and validate_metadata:
             self.validate_metadata_json(self.metadata_json)
 
-        return super().insert(session=session, commit=commit, compute_etag=compute_etag)
+        return super().insert(session=session, commit=commit)
 
     @with_default_session
     def update(
@@ -1509,6 +1510,18 @@ class TrialMetadata(CommonColumns):
                 pair#>'{report,report}' is not null
             group by
                 trial_id
+            union all
+            select
+                trial_id,
+                'wes_analysis' as key,
+                count(*) as value
+            from
+                trial_metadata,
+                jsonb_array_elements(metadata_json#>'{analysis,wes_analysis_old,pair_runs}') pair
+            where
+                pair#>'{report,report}' is not null
+            group by
+                trial_id
         """
 
         wes_tumor_only_analysis_subquery = """
@@ -1518,6 +1531,13 @@ class TrialMetadata(CommonColumns):
                 jsonb_array_length(metadata_json#>'{analysis,wes_tumor_only_analysis,runs}') as value
             from
                 trial_metadata
+            union all
+            select
+                trial_id,
+                'wes_tumor_only_analysis' as key,
+                jsonb_array_length(metadata_json#>'{analysis,wes_tumor_only_analysis_old,runs}') as value
+            from
+                trial_metadata
         """
 
         # Count the tumor samples that will have associated paired-analysis data.
@@ -1534,6 +1554,16 @@ class TrialMetadata(CommonColumns):
                 jsonb_array_elements(metadata_json#>'{analysis,wes_analysis,pair_runs}') pair
             group by
                 trial_id
+            union all
+            select
+                trial_id,
+                'wes' as key,
+                count(*) as value
+            from
+                trial_metadata,
+                jsonb_array_elements(metadata_json#>'{analysis,wes_analysis_old,pair_runs}') pair
+            group by
+                trial_id
         """
 
         # Count the tumor samples that DON'T have associated paired-analysis data.
@@ -1575,6 +1605,16 @@ class TrialMetadata(CommonColumns):
                 jsonb_array_elements(metadata_json#>'{analysis,wes_analysis,pair_runs}') pair
             group by
                 trial_id
+            union all
+            select
+                trial_id,
+                'wes_tumor_only' as key,
+                -count(*) as value
+            from
+                trial_metadata,
+                jsonb_array_elements(metadata_json#>'{analysis,wes_analysis_old,pair_runs}') pair
+            group by
+                trial_id
         """
 
         rna_level1_analysis_subquery = """
@@ -1661,6 +1701,13 @@ class TrialMetadata(CommonColumns):
                     from
                         trial_metadata
                     union all
+                    select
+                        trial_id,
+                        'wes_analysis' as key,
+                        jsonb_array_elements(metadata_json#>'{analysis,wes_analysis_old,excluded_samples}') as sample
+                    from
+                        trial_metadata
+                    union all
                     select
                         trial_id,
                         'wes_tumor_only_analysis' as key,
@@ -1668,6 +1715,13 @@ class TrialMetadata(CommonColumns):
                     from
                         trial_metadata
                     union all
+                    select
+                        trial_id,
+                        'wes_tumor_only_analysis' as key,
+                        jsonb_array_elements(metadata_json#>'{analysis,wes_tumor_only_analysis_old,excluded_samples}') as sample
+                    from
+                        trial_metadata
+                    union all
                     select
                         trial_id,
                         'rna_level1_analysis' as key,
